@@ -1,6 +1,6 @@
 use santiago::grammar::Grammar;
 
-pub fn grammar() -> Grammar {
+pub fn grammar() -> Grammar<()> {
     santiago::grammar!(
         "sum" => rules "sum" "plus" "sum";
         "sum" => lexemes "INT";
